@@ -23,7 +23,7 @@ use vars qw( @ISA $VERSION $drh $err $errstr $sqlstate );
 
 @ISA =   qw( DBD::File );
 
-$VERSION  = "0.35";
+$VERSION  = "0.36";
 
 $err      = 0;		# holds error code   for DBI::err
 $errstr   = "";		# holds error string for DBI::errstr
@@ -441,6 +441,15 @@ $DBD::File::VERSION > 0.38 and *open_file = sub {
 	}
     }; # open_file
 
+sub _csv_diag
+{
+    my @diag = $_[0]->error_diag;
+    for (2, 3) {
+	defined $diag[$_] or $diag[$_] = "?";
+	}
+    return @diag;
+    } # _csv_diag
+
 sub fetch_row
 {
     my ($self, $data) = @_;
@@ -458,9 +467,9 @@ sub fetch_row
     unless ($fields) {
 	$csv->eof and return;
 
-	my @diag = $csv->error_diag;
+	my @diag = _csv_diag ($csv);
 	my $file = $DBD::File::VERSION <= 0.38 ? $self->{file} : $tbl->{f_fqfn};
-	croak "Error $diag[0] while reading file $file: $diag[1]";
+	croak "Error $diag[0] while reading file $file: $diag[1] \@ line $diag[3] pos $diag[2]";
 	}
     @$fields < @{$tbl->{col_names}} and
 	push @$fields, (undef) x (@{$tbl->{col_names}} - @$fields);
@@ -475,9 +484,9 @@ sub push_row
     my $fh  = $tbl->{fh};
 
     unless ($csv->print ($fh, $fields)) {
-	my @diag = $csv->error_diag;
+	my @diag = _csv_diag ($csv);
 	my $file = $DBD::File::VERSION <= 0.38 ? $self->{file} : $tbl->{f_fqfn};
-	croak "Error $diag[0] while writing file $file: $diag[1]";
+	croak "Error $diag[0] while writing file $file: $diag[1] \@ line $diag[3] pos $diag[2]";
 	}
     1;
     } # push_row
